@@ -22,6 +22,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <libosso.h>
 #include <hildon/hildon-help.h>
 #include <hildon/hildon-window.h>
@@ -37,9 +41,12 @@
 #include "hcp-app-view.h"
 #include "hcp-app.h"
 #include "hcp-grid.h"
-#include "hcp-rfs.h"
 #include "hcp-config-keys.h"
 
+#ifdef MAEMO_TOOLS
+#include "hcp-rfs.h"
+#endif
+
 #define HCP_WINDOW_GET_PRIVATE(object) \
         (G_TYPE_INSTANCE_GET_PRIVATE ((object), HCP_TYPE_WINDOW, HCPWindowPrivate))
 
@@ -126,7 +133,7 @@ hcp_window_enforce_state (HCPWindow *window)
 
     app = g_hash_table_lookup (apps,
                                priv->saved_focused_filename);
-
+    
     if (app)
       hcp_app_focus (app);
 
@@ -300,7 +307,7 @@ hcp_window_save_state (HCPWindow *window, gboolean clear_state)
 
   if (ret != OSSO_OK)
   {
-    g_warning ("An error occured when reading application state");
+    g_warning ("An error occured when writing application state");
   }
 
   /* If a plugin is running, save its state */
@@ -332,7 +339,6 @@ hcp_window_retrieve_configuration (HCPWindow *window)
   GConfClient *client = NULL;
   GError *error = NULL;
   gboolean icon_size;
-  gint lock_state;
   
   g_return_if_fail (window);
   g_return_if_fail (HCP_IS_WINDOW (window));
@@ -357,12 +363,11 @@ hcp_window_retrieve_configuration (HCPWindow *window)
     priv->icon_size = icon_size ? TRUE : FALSE;
   }
 
-  lock_state = gconf_client_get_int (client,
-                                     HCP_GCONF_LOCK_STATE_KEY,
-                                     &error);
+  priv->device_locked = 
+          gconf_client_get_bool (client,
+                                 HCP_GCONF_LOCK_STATE_KEY,
+                                 &error);
 
-  priv->device_locked = (lock_state > 0);
- 
   g_object_unref (client);
 }
 
@@ -489,6 +494,7 @@ hcp_window_launch_help (GtkWidget *widget, HCPWindow *window)
   }
 }
 
+#ifdef MAEMO_TOOLS
 static gboolean 
 hcp_window_clear_user_data (GtkWidget *widget, HCPWindow *window)
 {
@@ -556,6 +562,7 @@ hcp_window_run_operator_wizard (GtkWidget *widget, HCPWindow *window)
   
   osso_rpc_free_val (&returnvalues);
 }
+#endif
 
 static void 
 hcp_window_iconsize (GtkWidget *widget, HCPWindow *window)
@@ -673,6 +680,7 @@ hcp_window_app_list_updated_cb (HCPAppList *al, HCPWindow *window)
 
   /* Update the view */
   hcp_app_view_populate (HCP_APP_VIEW (priv->view), al);
+
   gtk_widget_show_all (priv->view);
 
   app = g_hash_table_lookup (apps,
@@ -691,7 +699,7 @@ static void hcp_window_quit (GtkWidget *widget, HCPWindow *window)
   g_return_if_fail (window);
   g_return_if_fail (HCP_IS_WINDOW (window));
 
-  hcp_window_save_state (window, TRUE);
+  hcp_window_save_state (window, FALSE);
 
   gtk_widget_destroy (GTK_WIDGET (window));
 
@@ -706,8 +714,11 @@ hcp_window_construct_ui (HCPWindow *window)
   HildonProgram *program;
   
   GtkMenu *menu = NULL;
+  GtkAccelGroup *accel_group;
   GtkWidget *sub_view = NULL;
+#ifdef MAEMO_TOOLS
   GtkWidget *sub_tools = NULL;
+#endif
   GtkWidget *mi = NULL;
   GtkWidget *scrolled_window = NULL;
   GSList *menugroup = NULL;
@@ -796,6 +807,7 @@ hcp_window_construct_ui (HCPWindow *window)
   g_signal_connect (G_OBJECT (mi), "activate", 
                     G_CALLBACK (hcp_window_iconsize), window);
 
+#ifdef MAEMO_TOOLS
   /* Tools submenu */
   sub_tools = gtk_menu_new ();
 
@@ -829,21 +841,36 @@ hcp_window_construct_ui (HCPWindow *window)
 
   g_signal_connect (G_OBJECT (mi), "activate",
                     G_CALLBACK (hcp_window_clear_user_data), window);
-
+#endif
+  
   /* Help! */
   mi = gtk_menu_item_new_with_label (HCP_MENU_HELP);
 
+#ifdef MAEMO_TOOLS
   gtk_menu_shell_append (GTK_MENU_SHELL (sub_tools), mi);
+#else
+  gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
+#endif
 
   g_signal_connect(G_OBJECT (mi), "activate",
                    G_CALLBACK (hcp_window_launch_help), window);
 
   /* Close */
+  accel_group = gtk_accel_group_new ();
+  gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
+  
   mi = gtk_menu_item_new_with_label (HCP_MENU_CLOSE);
 
   g_signal_connect (GTK_OBJECT(mi), "activate",
                     G_CALLBACK(hcp_window_quit), window);
 
+  gtk_widget_add_accelerator (mi, 
+		              "activate", 
+			      accel_group, 
+			      GDK_Q, 
+			      GDK_CONTROL_MASK, 
+			      GTK_ACCEL_VISIBLE);
+  
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
 
   gtk_widget_show_all (GTK_WIDGET (menu));
